# :Author: SAKIMA Kimihisa
# :Contact: sakima at hooktail.org
# :Date: $Date: 2007/02/24 12:53:30 $
# :Revision: $Revision: 1.4 $

$KCODE = "EUC"


# ==========================================================
# ɥȥ饹
# ==========================================================
def documentclass(buf, style)
  
  if style == "report"
    pkg_name = "kagipdf_report"
    class_name = "jsarticle"
    class_opt = "11pt,a4paper"
  elsif style == "thesis"
    pkg_name = "kagipdf_thesis"
    class_name = "jsbook"
    class_opt = "12pt,a4paper,oneside,openany"
  else
    pkg_name = "kagipdf_hooktail"
    class_name = "jsarticle"
    class_opt = "11pt,a4paper"
  end
  
  # ɥȥ饹ִ\usepakage{pkg_name} ɲ
  buf.sub!(/^\\documentclass.*$/,
  "\\documentclass\[#{class_opt}\]\{#{class_name}\}\n\\usepackage\{#{pkg_name}\}\n\\usepackage\{mydefinition\}")
  
  return buf
  
end


# ==========================================================
# ץꥢ֥
# ==========================================================
def preamble(buf, style)
  
  # color, graphicx ѥåФ dvipdfm ץɲ
  buf.sub!(/\\usepackage\{color\}/, "\\usepackage\[dvipdfm\]\{color\}")
  buf.sub!(/\\usepackage\{graphicx\}/, "\\usepackage\[dvipdfm\]\{graphicx\}")

  # Ⱥѥå̿
  buf.sub!(/\\usepackage\[DIV12\]\{typearea\}\n/, "")
  buf.sub!(/\\usepackage\{ae\}\n/, "")
  buf.sub!(/\\usepackage\[.*\]\{inputenc\}\n/, "")
  buf.sub!(/\\usepackage\{babel\}\n/, "")
  buf.sub!(/\\usepackage\{aeguill\}\n/, "")

  # amssymb, bm ѥåɲ
  buf.sub!(/\\usepackage\{amsmath\}/, "\\usepackage\{amsmath,amssymb,bm\}")

  # hyperref ѥåΥץѹ
  buf.sub!(/\\usepackage\[colorlinks=(\w+),linkcolor=(\w+),urlcolor=(\w+)\]\{hyperref\}/){
    "\\usepackage\[dvipdfm,bookmarks=true,bookmarksnumbered=true,pdfstartview=\{FitH -32768\}," +
    "colorlinks=#{$1},linkcolor=#{$2},urlcolor=#{$3},citecolor=#{$3}" +
    "\]\{hyperref\}" +
    "\\ifnum 42146=\\euc\"A4A2 \\AtBeginDvi\{\\special\{pdf:tounicode EUC-UCS2\}\}\\else" +
    "\\AtBeginDvi\{\\special\{pdf:tounicode 90ms-RKSJ-UCS2\}\}\\fi  %\""
  }
  
  return buf
  
end


# ==========================================================
# latexȥ
# ==========================================================
def textitle(buf, style)
  
  if style == "hooktail"
    # authorˡ֡ʪΤץȡפä
    buf.gsub!(/\\author\{(.*?)\}/){"\\author\{" + $1 + "ʪΤץ\}"}
    buf.gsub!(/pdfauthor=\{(.*?)\}/){"pdfauthor=\{" + $1 + "ʪΤץ\}"}
  end
  
  # :Date: today  \date{\today}
  buf.gsub!(/\\date\{today\}/, "\\date\{\\today\}")
  
  return buf
  
end


# ==========================================================
# latexʸ
# ==========================================================
def texbody(buf, style)
 
  # ̾ĤǤ
  unless style == "thesis"
    buf.gsub!(/\\includegraphics/, "\\includegraphics\[scale=0\.55\]")
    buf.gsub!(/\\includegraphics(.*\}$)/){
      "\\begin\{center\}\\includegraphics" + $1 + "\\end\{center\}"
    }
  end

  # \end{quote} \end{itemize} θβԤ
  buf.gsub!(/(^\\begin\{quote\}).*?\n/){ $1 }
  buf.gsub!(/(^\\end\{quote\}).*?\n/){ $1 }
  buf.gsub!(/(^\\end\{itemize\}).*?\n/){ $1 }
  buf.gsub!(/(^\\end\{list\}).*?\n/){ $1 }
  
  # ;ʬʶ
  buf.gsub!(/ ?([]) ?/){ $1 }
  buf.gsub!(/ ?(\\ref\{.*?\}) ?/){ $1 }
  buf.gsub!(/ ?(\$\\ref\{.*?\}\$) ?/){ $1 }
  
=begin
  # ֹĤʤ
  DO_NOT_NUMBERING = [
  'ռ',
  'acknowledgment'
  ]
  buf.gsub!(/\\chapter\{(#{DO_NOT_NUMBERING[0]})\}/){
    "\chapter*{#{$1}}\n\addcontentsline{toc}{chapter}{#{$1}}"
  }
=end
  
  # \href{...} % 򥨥
  buf = buf.gsub(/\\href\{(.*?)\}/){
    "\\href\{" + $1.gsub(/%/, "\\%") + "\}"
  }

  unless style == "hooktail"
    buf.gsub!(/\\section\*\{/, "\\section\{")
    buf.gsub!(/\\subsection\*\{/, "\\subsection\{")
  end
  
  if style == "thesis"
    buf.sub!(/\\begin\{center\}.*?\\begin\{tabularx\}\{\\docinfowidth\}\{lX\}.*?\\end\{tabularx\}.*?\\end\{center\}.*?\\setlength\{\\locallinewidth\}\{\\linewidth\}.*?\\tableofcontents.*?\\bigskip/m, "\\frontmatter\n\\tableofcontents\n\\mainmatter")
    buf.gsub!(/\\section\{ռ\}/, '\chapter*{ռ}\addcontentsline{toc}{chapter}{ռ}')
    buf.gsub!(/\\section/, '\chapter')
    buf.gsub!(/\\subsection/, '\section')
    buf.gsub!(/\\subsubsection/, '\subsection')
    buf.gsub!(/ ?\$(\\cite\{.*?\})\$ ?/){ "~#{$1}" }
  end
  
  return buf
  
end
